# [Logtail](https://betterstack.com/logtail) Python client by [Better Stack](https://betterstack.com/)
  
  [![Logtail python client](https://user-images.githubusercontent.com/19272921/154085622-59997d5a-3f91-4bc9-a815-3b8ead16d28d.jpeg)](https://betterstack.com/logtail)


[![ISC License](https://img.shields.io/badge/license-ISC-ff69b4.svg)](LICENSE.md)
[![PyPI package](https://badge.fury.io/py/logtail-python.svg)](https://badge.fury.io/py/logtail-python)
![Logtail python client](https://github.com/logtail/logtail-python/actions/workflows/main.yml/badge.svg?branch=master)

Experience SQL-compatible structured log management based on ClickHouse. [Learn more ⇗](https://logtail.com/)

## Documentation

[Getting started ⇗](https://betterstack.com/docs/logs/javascript/)

## Need help?
Please let us know at [hello@betterstack.com](mailto:hello@betterstack.com). We're happy to help!

---

[ISC license](https://github.com/logtail/logtail-js/blob/master/LICENSE.md), [example project](https://github.com/logtail/logtail-python/tree/master/example-project)
